==> centreon-web-24.10.16.tar.gz: centreon-web-24.10.16/src/Core/ServiceTemplate/Infrastructure/API/DeleteServiceTemplate/DeleteServiceTemplateController.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\ServiceTemplate\Infrastructure\API\DeleteServiceTemplate;

use Centreon\Application\Controller\AbstractController;
use Core\Infrastructure\Common\Api\DefaultPresenter;
use Core\ServiceTemplate\Application\UseCase\DeleteServiceTemplate\DeleteServiceTemplate;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;

final class DeleteServiceTemplateController extends AbstractController
{
    /**
     * @param DeleteServiceTemplate $useCase
     * @param DefaultPresenter $presenter
     * @param int $serviceTemplateId
     *
     * @throws AccessDeniedException
     *
     * @return Response
     */
    public function __invoke(
        DeleteServiceTemplate $useCase,
        DefaultPresenter $presenter,
        int $serviceTemplateId
    ): Response {
        $this->denyAccessUnlessGrantedForApiConfiguration();

        $useCase($serviceTemplateId, $presenter);

        return $presenter->show();
    }
}

==> centreon-web-24.10.21.tar.gz: centreon-web-24.10.21/src/Core/ServiceTemplate/Infrastructure/API/DeleteServiceTemplate/DeleteServiceTemplateController.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\ServiceTemplate\Infrastructure\API\DeleteServiceTemplate;

use Centreon\Application\Controller\AbstractController;
use Core\Infrastructure\Common\Api\DefaultPresenter;
use Core\ServiceTemplate\Application\UseCase\DeleteServiceTemplate\DeleteServiceTemplate;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;

final class DeleteServiceTemplateController extends AbstractController
{
    /**
     * @param DeleteServiceTemplate $useCase
     * @param DefaultPresenter $presenter
     * @param int $serviceTemplateId
     *
     * @throws AccessDeniedException
     *
     * @return Response
     */
    public function __invoke(
        DeleteServiceTemplate $useCase,
        DefaultPresenter $presenter,
        int $serviceTemplateId,
    ): Response {
        $this->denyAccessUnlessGrantedForApiConfiguration();

        $useCase($serviceTemplateId, $presenter);

        return $presenter->show();
    }
}
